#!/bin/env pwsh

[CmdletBinding()]
Param(
    [switch] $Force
)

if ($IsLinux -and (-not $env:SUDO_UID))
{
    throw "this script must be run as root, aborting..."
}

if (-not (Get-Command "docker" -errorAction SilentlyContinue)) {
    throw "docker not installed, aborting...";
}

if (-not (Get-Command "docker-compose" -errorAction SilentlyContinue)) {
    throw "docker-compose not installed, aborting...";
}

Import-Module ./scripts/NetcoUtils

$confirmation = Read-Host "Are you sure you want to stop and clear Satel stack? This isn't meant to run during normal operation or during update. [y/N]"

if ($confirmation -and $confirmation.ToLower() -eq 'y') {
    $keepConfig = Read-Host "Do you want to preserve system configurations? [Y/n]"
    $bDeleteConfig = $keepConfig -and $keepConfig.ToLower() -eq 'n'
    if ($bDeleteConfig -eq $True) {
        Set-Content '.env.secret' -Value ""
    }
    docker-compose -p netco_nms down --remove-orphans
    if($bDeleteConfig -eq $True) {
        Remove-Item '.env.secret' -ErrorAction Ignore
        Remove-Item -Path (ResolveConfigFilePath) -ErrorAction Ignore
    }
} else {
    Write-Warning "Skipped down."
}
