#!/bin/env pwsh

param ($logsFromDays=10)

if ($IsLinux -and (-not $env:SUDO_UID))
{
    throw "this script must be run as root, aborting..."
}

$prefix = "netco_nms"
Write-Host "Generating diagnostics package for ${prefix}:"
Write-Host

if ($IsLinux ){
  $logPath = (docker volume inspect --format '{{.Mountpoint}}' ${prefix}_satel_programdata)
  if ($logPath -eq "") {
    Write-Host
    Write-Host "Has NETCO STACKS been launched from this folder?"
    [Environment]::Exit(1)
  }
}
else {
    $logPath = "$PsScriptRoot/__lastlogs"
    If(!(test-path -PathType container $logPath)){
       New-Item -Path $logPath -ItemType Directory
    }
    else {
        Remove-Item $PsScriptRoot/__lastlogs/* -Recurse -Force
    }
	$dsContainerName = docker ps --filter name=netco_nms.ds --format "{{.Names}}"
    Invoke-Expression "docker cp ${dsContainerName}:/usr/share/Satel/NETCO/ '$logPath'"
}
#$logsFromDays = 90

Add-Type -A System.IO.Compression.FileSystem
$zipFileName = "$PsScriptRoot/netco_nms_$(Get-Date -Format "yyyy-MM-dd_HHmmss")_ser.zip"
$zip = [System.IO.Compression.ZipFile]::Open($zipFileName, 'update')
$compressionLevel = [System.IO.Compression.CompressionLevel]::Optimal

Set-Location -Path $logPath
Get-ChildItem -Path . -Recurse -Include ('*.log','package_config*.json') `
 | Where-Object {($_.LastWriteTime -gt (Get-Date).AddDays(-1 * $logsFromDays))} `
 | ForEach-Object {
     $logFile = $_.FullName
     $logPrefixLength = $logPath.length
     $logZipPath = $logFile.Remove(0, $logPrefixLength)
     $logZipPath = $logZipPath.TrimStart("/")
	 $logZipPath = $logZipPath.TrimStart("\")
     Write-Host "  $($logZipPath)"
     [System.IO.Compression.ZipFileExtensions]::CreateEntryFromFile($zip, $logFile, $logZipPath, $compressionLevel) 1>$null
 }

$zip.Dispose()
Write-Host
Write-Host "Generated file: ${zipFileName}"
Set-Location -Path $PsScriptRoot
