#!/bin/bash
/run.sh & run_pid=$!

create_default_users()
{
    printf "Creating default users...\n"

    editor_id=$(curl -u admin:admin -X POST -s \
        -H "Content-Type: application/json" \
        -d '{"name":"editor","email":"editor@localhost","login":"editor","password":"editor", "role": "Editor"}' \
        http://localhost:3000/api/admin/users | grep -oP '"id":\K.*?(?=,)')

    viewer_id=$(curl -u admin:admin -X POST -s \
        -H "Content-Type: application/json" \
        -d '{"name":"viewer","email":"viewer@localhost","login":"viewer","password":"viewer", "role": "Viewer"}' \
        http://localhost:3000/api/admin/users | grep -oP '"id":\K.*?(?=,)')

    curl -u admin:admin -X PATCH \
        -H "Content-Type: application/json" \
        -d '{"role": "Editor"}' \
        http://localhost:3000/api/org/users/$editor_id

    curl -u admin:admin -X PATCH \
        -H "Content-Type: application/json" \
        -d '{"role": "Viewer"}' \
        http://localhost:3000/api/org/users/$viewer_id
}

set_custom_homepage()
{
    local dashboard_uid=$1

    printf "Setting home dashboard to $dashboard_uid...\n"

    dashboard_id=$(curl -u admin:admin -s \
        -H "Content-Type: application/json" \
        http://localhost:3000/api/dashboards/uid/$dashboard_uid | grep -oP '"id":\K.*?(?=,)' | head -1)

    curl -u admin:admin -X PUT \
        -H 'Content-Type: application/json' \
        -d "{\"homeDashboardId\":${dashboard_id},\"theme\":\"\",\"timezone\":\"\"}" \
        http://localhost:3000/api/org/preferences
}

# Wait for run.sh to finish
while ! timeout 1s curl -sSfI localhost:3000 > /dev/null
do
    sleep 1s
    printf "Waiting for server...\n"
done

create_default_users
set_custom_homepage _hnuYaGZz

wait $run_pid
