local jwt = require "resty.jwt"
local http = require "resty.http"
local cjson = require "cjson"

local redirect = "false";
local status = "";

local function has_value (tab, val)
    for index, value in ipairs(tab) do
        if value == val then
            return true
        end
    end

    return false
end

local function starts_with (base, to_match)
    return string.sub(base, 1, string.len(to_match)) == to_match
end

-- Fetch the token from cookie
local token = ngx.var['cookie_netco|token'];
if token == nil then
    redirect = "true";
    status = "NO_TOKEN";
else
    -- Verify the token using secret key
    local secret = os.getenv("SECRET") or "secret";
    local jwt_obj = jwt:verify(secret, token)
    if not jwt_obj["verified"] then
        redirect = "true";
        status = "INVALID_TOKEN";
    else
        -- Fetching data from JWT payload
        local userRoles = jwt_obj.payload.orgs[1].roles;

        if has_value(userRoles, 'ms-grafana-admin') then
            ngx.req.set_header('X-WEBAUTH-USER', 'admin');
        elseif has_value(userRoles, 'ms-grafana-editor') then
            ngx.req.set_header('X-WEBAUTH-USER', 'editor');
        elseif has_value(userRoles, 'ms-grafana-viewer') then
            ngx.req.set_header('X-WEBAUTH-USER', 'viewer');
        else
            ngx.status = ngx.HTTP_FORBIDDEN
            ngx.header.content_type = "application/json; charset=utf-8"
            ngx.say(cjson.encode({ status = "NO_ACCESS" }))
            return ngx.exit(ngx.HTTP_FORBIDDEN)
        end
    end
end
if redirect == "true" then
    if starts_with(ngx.var.request_uri, '/grafana/api') then
        ngx.status = ngx.HTTP_UNAUTHORIZED
        ngx.header.content_type = "application/json; charset=utf-8"
        ngx.say(cjson.encode({ status = status }))
    else
        ngx.redirect('/monitoring/logout')
    end
end