![](img/netco_logo.png)

<a name="table-of-contents" class="anchor"></a>
- [Introduction](#introduction)
  - [System requirements](#system-requirements)
- [Installing](#installing)
  - [1. Copy the package to the target machine](#1-copy-the-package-to-the-target-machine)
  - [2. Extract archive and open terminal in created folder](#2-extract-archive-and-open-terminal-in-created-folder)
  - [3a. Launch installer in the terminal](#3a-launch-installer-in-the-terminal)
  - [3b. Installation instructions for Windows 10](#3b-installation-instructions-for-windows-10)
  - [4. Initial configuration](#4-initial-configuration)
  - [5. Installation complete](#5-installation-complete)
- [Updating](#updating)
- [Uninstalling](#uninstalling)
- [Accessing NETCO NMS](#accessing-netco-nms)
- [Logging in](#logging-in)
- [Main menu](#main-menu)
- [Serial ports setup in Windows](#serial-ports-setup-in-windows)
  - [1. Helper scripts](#1-helper-scripts)
    - [1.1 Create port mapping](#11-create-port-mapping)
    - [1.2 Update port mapping](#12-update-port-mapping)
    - [1.3 Delete port mapping](#13-delete-port-mapping)
    - [1.4 Temporary Stop and Start mapping](#14-temporary-stop-and-start-mapping)
    - [1.5 Get port mapping info](#15-get-port-mapping-info)
  - [2. Connection from NETCO Design](#2-connection-from-netco-design)
- [Troublshooting](#troublshooting)
  - [Running into issues](#running-into-issues)
  - [Lost password](#lost-password)
  - [Error reporting](#error-reporting)

**NOTE: This document describes only installation and login to NETCO NMS. Full documentation is available form NETCO NMS menu.**

# Introduction

SATEL NETCO NMS is an intuitive and user-friendly network configuration software for network design and management with radio network monitoring option. The software supports configuration of the Routing Setup and NMS Routing Setup modes for SATEL-EASy+ product family. NMS Routing refers to NMS (Network Management System) Message Routing feature, where messages can be automatically routed over the radio network to correct recipient terminal, monitoring and diagnostics included for the radio network. Graphical design of topology for NMS Message Routing, remote modification of settings, online storing and trending of field data with programmable alarm triggers. Routing Setup refers to Message Routing feature for SATEL-EASy+, SATELLINE-3AS NMS family radio modems, where messages can be automatically routed over the radio network to correct recipient terminal.

The user interface of the product is web-browser-based and can therefore be used both locally and remotely. Design with graphical user interface for easy optimizing network design and deployment in a few simple steps, with local and remote connection to SATEL radios. SATEL NETCO Design supports also .saxd file format, configuration files created with the SATEL NMS PC SW. Installation requires valid, company specific license key. License keys are available from [your local SATEL distributor](https://www.satel.com/where-to-buy/) or from SATEL directly.

SATEL NETCO NMS includes the following tools:

- [SATEL NETCO Design](https://www.satel.com/products/software/netco/) for network management
- [Alerta](https://alerta.io/) for alert management
- [Docker](https://www.docker.com/) for containerization
- [Grafana](https://grafana.com/) for displaying monitoring information
- [InfluxDB](https://www.influxdata.com/) for time series database


## System requirements

The system requirements are:

- Modern 4+ Core cpu.
- 8GB+ of memory.
- 1TB+ disk space.
- Ubuntu 20.04 LTS or Windows 10 or 11 with Windows Subsystem for Linux (WSL2).

Additional requirements for Windows installations:

- Requires Windows 10 64-bit Pro/Enterprise (version ~2019.09 or newer) or Windows 11.
- Requires at least one hard drive which is not Bitlocker protected
- Using other hypervisors than Microsoft Hyper-V required by WSL2 is not recommended and can lead to failure of installation or operation.
- Local Administrator rights are required
- ExecutionPolicy must allow running PowerShell scripts (see: [Enable Unrestricted Execution Policy](install.md#enable_unrestricted_execution_policy))


# Installing 

NETCO NMS installation packages are distributed in .zip file format.

## 1. Copy the package to the target machine

Ensure the target machine adheres to the [system requirements](#system-requirements)

## 2. Extract archive and open terminal in created folder

Open the target folder with NETCO NMS package in the file manager: ![File manager icon](img/installation_file_manager_icon.png)

Right click on the zip file and select ***Extract here***.

Next, right click on the created folder and select ***Open in Terminal***.

![Extracting zip file](img/installation_extract.png)![Extracting zip file](img/installation_open_terminal.png)

## 3a. Launch installer in the terminal

Issue the following commands:

> chmod +x ./environments/compose-for-single-node-linux.sh<br>
> sudo ./environments/compose-for-single-node-linux.sh<br>
> sudo ./LocalUp.ps1

## 3b. Installation instructions for Windows 10

1. Download Docker Desktop for Windows

[https://www.docker.com/products/docker-desktop](https://www.docker.com/products/docker-desktop)

2. Install Docker Desktop for Windows.

If it is requested, please create docker.com user account.

Accept default suggestions:

[x] Install required Windows components for WSL2

[x] add shortcut to Desktop


3. Enable Unrestricted Execution Policy

To enable running Powershell scripts, start Powershell with "Run as Administrator" and run the following:

`Set-Executionpolicy Unrestricted`

This will prompt:

> Execution Policy Change
> The execution policy helps protect you from scripts that you do not trust. Changing the execution policy might expose
> you to the security risks described in the about_Execution_Policies help topic at
> https:/go.microsoft.com/fwlink/?LinkID=135170. Do you want to change the execution policy?
> [Y] Yes  [A] Yes to All  [N] No  [L] No to All  [S] Suspend  [?] Help (default is "N"):

Type **a** and press Enter.

4. Start the NETCO NMS stack

Now go to the directory where you extracted the zip with the Administrator terminal, and run this:

`.\LocalUp.ps1`

(!) If you are asked to trust .ps1 scripts in this
   directory during the following steps, please choose
   option R = Run once. You may have to do this 2-3 times
   during installation.

You will be presented a menu where you can change configuration. See more information about the menu in next chapter.

The installation takes some minutes and after that you are presented with an url to direct your browser to and admin username and password. Please save the password for later logins as it is the only way to login as admin.

## 4. Initial configuration

At first LocalUp.ps1 will allow making changes to the initial configuration. The available options are:

**Option** |**OS**| **Description**
|:--   | :--- |:--
|1. Allow access to local serial device: none |Linux| For installations where a local serial port on the NETCO NMS machine is used to access the radio network's root node. Common examples may be ***/dev/ttyS0*** or ***/dev/ttyUSB0***. The ttyS* devices are typically hardware serial ports directly on the computer's motherboard. For USB serial adapters the device name can be obtained by looking at `dmesg |tail` output immediately after the adapter has been connected.
|2. Listen address for NETCO NMS user interface: 0.0.0.0 | Win Linux|The default listens to all network interfaces. If NETCO NMS should be restricted to a specific network interface, provide its IP address here.
|3. Listen port for NETCO NMS user interface: 80 | Win Linux | Listen port
|4. Retention policy for monitoring data: INF |Win Linux| The time to store monitoring data in the database. The value must be either a number and unit [e.g. '105d'] or 'INF', which will never delete monitoring data. **Note: This can not be changed later.**
|5. Internal Docker address space: 10.99.99.0/24 |Win Linux| NETCO NMS creates a subnet to communicate across its components locally. This address space is not otherwise visible to NETCO NMS users, however it should not collide with networks within the Intranet.
|6. User profile path | Win | NETCO NMS istaller will configure WSL2 to limit memory usage with 4Gb. A file ".wslconfig" will be saved to the user profile folder.

Note: If you are installing NETCO NMS on a Windows machine and wish to establish a serial connection to your devices, it is recommended to utilize port mapping scripts, which can be found in ./win_ports folder. These scripts assist in mapping TCP ports within the Docker container to the serial port on your Windows host machine. More information is in a chapter [Serial ports setup in Windows](#serial-ports-setup-in-windows)

When ***Configure option:*** is prompted, most users can simply press Enter to continue with default settings.

![NETCO NMS LocalUp.ps1 start example](img/installation_localup_example1.png)


## 5. Installation complete

Once installation is completed, the terminal will return to a command prompt. NETCO NMS is now installed and running. It will also be started automatically on reboot.

![NETCO NMS LocalUp.ps1 completed example](img/installation_localup_example2.png)

Follow the instructions in green to log in to NETCO NMS. The displayed password is randomly generated and is unique to each system. **Make sure to store or change the password for later use.**

# Updating

Simply extract a newer NETCO NMS package to some folder and run LocalUp.ps1.

**Note**: A new initial admin password will be generated. If you wish to use your previous admin password, please ensure to copy the .env.secret file from the directory where your previous version of NETCO NMS was extracted before running LocalUp.ps1.


# Uninstalling

Uninstallation involves the following three step process:

* Shut down the NETCO NMS stack:
 * on Ubuntu: open a terminal, enter the extracted NETCO NMS folder and run `sudo ./LocalDown.ps1`
 * on Windows: open a terminal by right clicking and selecting "Run as Administrator". Enter the extracted NETCO NMS folder and run `.\LocalDown.ps1`
* Remove unused docker images: `docker image prune -a`
* Remove unused docker volumes: `docker volume prune` -- this deletes NETCO NMS data including imported networks and monitoring data

These instructions assume docker was set up specifically for NETCO NMS. If additional dockers are installed, make sure to prune NETCO NMS specific containers and volumes only.





# Accessing NETCO NMS

Use a web browser to navigate to the host and port where NETCO NMS was installed. By default the address is [http://localhost/](http://localhost/), but configuration changes during installation may alter the used address. Accessing NETCO NMS will initially present the login page.

# Logging in

If the password has not been changed after installation, use the initial admin password as displayed in the final phase of the [installation instructions](#5-installation-complete).

If the password is lost, see the [Lost password section](#lost-password) on the Troubleshooting page.

<img src="img/usage_login_filled.png" style="width: 700px; object-fit: contain;" alt="Login page"/>

After logging in the user is presented with the Home dashboard.

<img src="img/usage_monitoring_home_dashboard.png" style="width: 700px; object-fit: contain;" alt="Home dashboard"/>

# Main menu

The top left corner includes a hamburger menu ![Hamburger menu](img/usage_hamburger_menu.png) which exposes the main menu to navigate across NETCO NMS components. As right click on the main menu does not work in NETCO Design, it is recommended to use the middle mouse button to open into a new tab from the main menu.

![Main menu](img/usage_main_menu.png)

# Serial ports setup in Windows

## 1. Helper scripts
Port mapping scripts help you to map TCP ports in Docker container to serial port in your host Windows machine.

An open source tool hub4com.exe is used to redirect serial to TCP/IP and TCP/IP to serial. https://sourceforge.net/projects/com0com/

The scripts are in __win_ports__ folder of NETCO NMS package.

### 1.1 Create port mapping

Run a script *create_port.bat* to install serial port mapping as a Windows service. The script starts the mapping, so it will be available even after PC restart.

NOTE! The script must be launched with __Administrator rights__.

__Parameters__:

 - Serial port at Windows machine.
 - Serial port baud rate
 - TCP port which should be mapped to the serial port

Example: *create_port.bat COM5 115200 8282*

### 1.2 Update port mapping

If you once installed port mapping, but you want to change its baud rate or TCP port, you should run create_port.bat with new parameters.

### 1.3 Delete port mapping

Use a script *delete_port.bat* to stop port mapping and uninstall the Windows service. It takes the serial port name as parameter. The script must be launched with __Administrator rights__.

Example: *delete_port.bat COM5*

### 1.4 Temporary Stop and Start mapping

You can temporary stop port mapping without uninstalling the Windows service, for example, to release the serial port. Use a script *stop_port.bat* for that and a script *start_port.bat* to start the Windows service back. The scripts take the serial port name as parameter and must be launched with __Administrator rights__.

Example: *stop_port.bat COM5*

### 1.5 Get port mapping info

Use a script *get_info.bat* to view what serial port mapping is in use, what are the parameters and the service status.

Running *get_info.bat* without parameters will display a mapped ports list.

Running *get_info.bat* with parameter specifying a serial port will display the port mapping details and its service status.

## 2. Connection from NETCO Design

Once the port mapping is installed you can access your device connected to that serial port with ip address *host.docker.internal* and TCP port which you specified for the mapping.

Example of connection string: *sockettcp:ip=host.docker.internal,port=8282*

# Troublshooting

## Running into issues

If there are issues with the way pages are rendered, a hard refresh is recommended with Ctrl+F5.

If the system is not responsive or appears to have stalled, a stack restart may help:

* Run in the extracted NETCO NMS folder:
  * In Ubuntu: `sudo ./LocalDown.ps1`
  * In Windows: `.\LocalDown.ps1` (Terminal must be run as Administrator)
* To the question `Are you sure you want to stop and clear Satel stack?` answer **y** and press enter
* To the question `Do you want to preserve system configurations?` answer **y** and press enter
* Now restart the stack with
  * In Ubuntu: `sudo ./LocalUp.ps1`
  * In Windows: `.\LocalUp.ps1` (Terminal must be run as Administrator)


## Lost password

If the admin password has not been changed after installation, it can still be recovered:

* Open the extracted NETCO NMS folder in the file manager
* Ubuntu users: enable "Show Hidden Files" from the top right hamburger menu in the file manager window. Windows users can skip this step.
* Double click ".env.secrets" to open the file in a text editor
* The password is displayed on the line `INITIAL_ADMIN_PASSWORD=...`

If admin password has been changed, it can be reset by restarting the stack:

* Run in the extracted NETCO NMS folder:
  * In Ubuntu: `sudo ./LocalDown.ps1`
  * In Windows: `.\LocalDown.ps1` (Terminal must be run as Administrator)
* To the question `Are you sure you want to stop and clear Satel stack?` answer **y** and press enter
* To the question `Do you want to preserve system configurations?` answer **n** and press enter to reset the admin password
* Now restart the stack:
  * In Ubuntu: `sudo ./LocalUp.ps1`
  * In Windows: `.\LocalUp.ps1` (Terminal must be run as Administrator)
* A new admin password will be generated and displayed similarly to during [installation](#5-installation-complete).


## Error reporting

Included with the installation is `LocalNETCODiagnostics.ps1` script which can be used to collect logs for diagnosing problems. Run in the extracted NETCO NMS folder:

* In Ubuntu: `sudo ./LocalNETCODiagnostics.ps1`
* In Windows: `.\LocalNETCODiagnostics.ps1` (Terminal must be run as Administrator)

The script collects logs for last 10 days. Pass a number of days as a parameter of the script, if you want to change the logs period.

Once the diagnostic ZIP-file has been generated, please send it to SATEL Technical support along with a description and preferably screenshots of the problem.

Example output:

> user@system .../netco_nms-1.27.5-716456fd.20093267 # sudo ./LocalNETCODiagnostics.ps1<br>
> [sudo] password for user:
>
> Generating diagnostics package for netco_nms:
>
>   controller0/logs/trace_2020-06-17.log<br>
>   controller0/logs/trace_2020-07-20_1.log<br>
>   controller0/logs/trace_2020-07-20_2.log<br>
>   ...
>
> Generated file: netco_nms_2020-09-11_113304_ser.zip

