function IpStringToDecimal([string]$ipAddress)
{
    $ipParts = $ipAddress.Split(".")
    $ipDecimal = 0

    [array]::Reverse($ipParts)
    For ($i = 0; $i -lt $ipParts.Length; $i++)
    { $ipDecimal += [Math]::Pow(256, $i) * [int]::Parse($ipParts[$i]) }

    return $ipDecimal
}

function GetSubCidrAddresses([string]$ipAddress, [int]$networkCount)
{
    [string[]]$subAddresses = @()
    $ip, $mask = $ipAddress -Split "/"

    # Calculate mask for single network
    $availableMaskForOne = [Math]::Ceiling(32 - [Math]::Log([Math]::Pow(2, 32 - [int]::Parse($mask)) / $networkCount, 2))
    $baseIpDec = IpStringToDecimal $ip

    For ($i = 0; $i -lt $networkCount; $i++)
    {
        $ipOffset = $i * [Math]::Pow(2, 32 - $availableMaskForOne)
        $startIp = [ipAddress]($baseIpDec + $ipOffset)
        $subAddresses += "$($startIp.ToString())/$($availableMaskForOne.ToString())"
    }

    return $subAddresses
}

function GetIpFromRange([string]$ipRange, [int]$index)
{
    $ip, $mask = $ipRange -Split "/"
    $countInRange = [Math]::Pow(2, 32 - [int]::Parse($mask)) - 2
    if ($index -gt $countInRange) { throw "Index $($index) is out of ip address range $($ipRange)" }
    return ([ipAddress]((IpStringToDecimal $ip) + $index)).ToString()
}

function GenerateNewSecret
{
    Add-Type -AssemblyName System.Security
    $rijndael = new-Object System.Security.Cryptography.RijndaelManaged
    $rijndael.GenerateKey()
    $secret = [Convert]::ToBase64String($rijndael.Key)
    $rijndael.Dispose()
    return $secret
}

function ResolveConfigFilePath {
    if ($IsLinux) {
        return "/etc/netco/nms/config.json"
    }
    else {
        return "$env:ProgramData/Satel/NETCO NMS/config.json"
    }
}

function GetConfig {
    try {
        return Get-Content (ResolveConfigFilePath) -ErrorAction Stop | Out-String | ConvertFrom-Json
    }
    catch {
        return @{}
    }
}

function UpdateConfig($config) {
    $outFile = New-Item -ItemType file -Path (ResolveConfigFilePath) -Force
    if (!($outFile)) { throw "Could not create configuration file." }
    Add-Content -Path $outFile -Value ($config | ConvertTo-Json) -Encoding "UTF8"
}
